@@ -52,6 +52,7 @@ const struct vpn_config invalid_cfg = {
 	.pinentry = NULL,
 	.realm = {'\0'},
 	.iface_name = {'\0'},
+	.sni = {'\0'},
 	.set_routes = -1,
 	.set_dns = -1,
 	.pppd_use_peerdns = -1,
@@ -93,7 +94,7 @@ const struct vpn_config invalid_cfg = {
  */
 int add_trusted_cert(struct vpn_config *cfg, const char *digest)
 {
-	struct x509_digest *last, *new;
+	struct x509_digest *new;
 
 	new = malloc(sizeof(struct x509_digest));
 	if (new == NULL)
@@ -106,7 +107,10 @@ int add_trusted_cert(struct vpn_config *cfg, const char *digest)
 	if (cfg->cert_whitelist == NULL) {
 		cfg->cert_whitelist = new;
 	} else {
-		for (last = cfg->cert_whitelist; last->next != NULL;
+		struct x509_digest *last;
+
+		for (last = cfg->cert_whitelist;
+		     last->next != NULL;
 		     last = last->next)
 			;
 		last->next = new;
@@ -195,7 +199,6 @@ int load_config(struct vpn_config *cfg, const char *filename)
 	// Read line by line
 	while ((read = getline(&line, &len, file)) != -1) {
 		char *key, *equals, *val;
-		int i;
 
 		// Ignore blank lines. We could argue that the string must be at least
 		// 3 chars to be valid, eg. 'x=\n' but let the rest of the function
@@ -223,13 +226,13 @@ int load_config(struct vpn_config *cfg, const char *filename)
 		while (isspace(val[0]))
 			val++;
 		// Remove trailing spaces
-		for (i = strlen(key) - 1; i > 0; i--) {
+		for (int i = strlen(key) - 1; i > 0; i--) {
 			if (isspace(key[i]))
 				key[i] = '\0';
 			else
 				break;
 		}
-		for (i = strlen(val) - 1; i > 0; i--) {
+		for (int i = strlen(val) - 1; i > 0; i--) {
 			if (isspace(val[i]))
 				val[i] = '\0';
 			else
@@ -298,6 +301,9 @@ int load_config(struct vpn_config *cfg, const char *filename)
 				continue;
 			}
 			cfg->set_dns = set_dns;
+		} else if (strcmp(key, "sni") == 0) {
+			strncpy(cfg->sni, val, GATEWAY_HOST_SIZE);
+			cfg->sni[GATEWAY_HOST_SIZE] = '\0';
 		} else if (strcmp(key, "set-routes") == 0) {
 			int set_routes = strtob(val);
 
@@ -536,6 +542,8 @@ void merge_config(struct vpn_config *dst, struct vpn_config *src)
 		strcpy(dst->realm, src->realm);
 	if (src->iface_name[0])
 		strcpy(dst->iface_name, src->iface_name);
+	if (src->sni[0])
+		strcpy(dst->sni, src->sni);
 	if (src->set_routes != invalid_cfg.set_routes)
 		dst->set_routes = src->set_routes;
 	if (src->set_dns != invalid_cfg.set_dns)
