@@ -385,7 +385,7 @@ static int pppd_run(struct tunnel *tunnel)
 #endif
 
 		if (close(tunnel->ssl_socket))
-			log_warn("Could not close ssl socket (%s).\n", strerror(errno));
+			log_warn("Could not close TLS socket (%s).\n", strerror(errno));
 		tunnel->ssl_socket = -1;
 		execv(pppd_args.data[0], (char *const *)pppd_args.data);
 		free(pppd_args.data);
@@ -561,7 +561,7 @@ static int pppd_terminate(struct tunnel *tunnel)
 
 int ppp_interface_is_up(struct tunnel *tunnel)
 {
-	struct ifaddrs *ifap, *ifa;
+	struct ifaddrs *ifap;
 
 	log_debug("Got Address: %s\n", inet_ntoa(tunnel->ipv4.ip_addr));
 
@@ -570,7 +570,7 @@ int ppp_interface_is_up(struct tunnel *tunnel)
 		return 0;
 	}
 
-	for (ifa = ifap; ifa != NULL; ifa = ifa->ifa_next) {
+	for (struct ifaddrs *ifa = ifap; ifa != NULL; ifa = ifa->ifa_next) {
 		if (
 #if HAVE_USR_SBIN_PPPD
 		        ((tunnel->config->pppd_ifname &&
@@ -626,17 +626,6 @@ static int get_gateway_host_ip(struct tunnel *tunnel)
 	return 0;
 }
 
-static int get_socket_option(int sockfd, int level, int optname)
-{
-	int optval;
-	socklen_t optlen = sizeof(optval);
-
-	if (getsockopt(sockfd, level, optname, &optval, &optlen) < 0)
-		return -1;
-	assert(optlen == sizeof(optval));
-	return optval;
-}
-
 /*
  * Establish a regular TCP connection.
  */
@@ -654,63 +643,6 @@ static int tcp_connect(struct tunnel *tunnel)
 		goto err_socket;
 	}
 
-	/*
-	 * Attempt to find default TCP socket options on different platforms.
-	 */
-#ifdef SO_KEEPALIVE
-	ret = get_socket_option(handle, SOL_SOCKET, SO_KEEPALIVE);
-	if (ret < 0)
-		log_warn("getsockopt: %s: %s\n", "SO_KEEPALIVE", strerror(errno));
-	else
-		log_debug("SO_KEEPALIVE: %s\n", (ret ? "ON" : "OFF"));
-#endif
-#ifdef TCP_KEEPIDLE
-	ret = get_socket_option(handle, IPPROTO_TCP, TCP_KEEPIDLE);
-	if (ret < 0)
-		log_warn("getsockopt: %s: %s\n", "TCP_KEEPIDLE", strerror(errno));
-	else
-		log_debug("TCP_KEEPIDLE: %d\n", ret);
-#endif
-#ifdef TCP_KEEPALIVE
-	ret = get_socket_option(handle, IPPROTO_TCP, TCP_KEEPALIVE);
-	if (ret < 0)
-		log_warn("getsockopt: %s: %s\n", "TCP_KEEPALIVE", strerror(errno));
-	else
-		log_debug("TCP_KEEPALIVE: %d\n", ret);
-#endif
-#ifdef TCP_KEEPINTVL
-	ret = get_socket_option(handle, IPPROTO_TCP, TCP_KEEPINTVL);
-	if (ret < 0)
-		log_warn("getsockopt: %s: %s\n", "TCP_KEEPINTVL", strerror(errno));
-	else
-		log_debug("TCP_KEEPINTVL: %d\n", ret);
-#endif
-#ifdef TCP_KEEPCNT
-	ret = get_socket_option(handle, IPPROTO_TCP, TCP_KEEPCNT);
-	if (ret < 0)
-		log_warn("getsockopt: %s: %s\n", "TCP_KEEPCNT", strerror(errno));
-	else
-		log_debug("TCP_KEEPCNT: %d\n", ret);
-#endif
-#ifdef SO_SNDBUF
-	ret = get_socket_option(handle, SOL_SOCKET, SO_SNDBUF);
-	if (ret < 0)
-#ifndef __APPLE__
-		log_warn("getsockopt: %s: %s\n", "SO_SNDBUF", strerror(errno));
-	else
-#endif
-		log_debug("SO_SNDBUF: %d\n", ret);
-#endif
-#ifdef SO_RCVBUF
-	ret = get_socket_option(handle, SOL_SOCKET, SO_RCVBUF);
-	if (ret < 0)
-#ifndef __APPLE__
-		log_warn("getsockopt: %s: %s\n", "SO_RCVBUF", strerror(errno));
-	else
-#endif
-		log_debug("SO_RCVBUF: %d\n", ret);
-#endif
-
 	if (iface_len == IF_NAMESIZE) {
 		log_error("socket: Too long iface name\n");
 		goto err_post_socket;
@@ -917,8 +849,6 @@ static int ssl_verify_cert(struct tunnel *tunnel)
 	unsigned int len;
 	struct x509_digest *elem;
 	char digest_str[SHA256STRLEN], *subject, *issuer;
-	char *line;
-	int i;
 	X509_NAME *subj;
 	char *saveptr = NULL;
 
@@ -951,7 +881,7 @@ static int ssl_verify_cert(struct tunnel *tunnel)
 		goto free_cert;
 	}
 	// Encode digest in base16
-	for (i = 0; i < SHA256LEN; i++)
+	for (int i = 0; i < SHA256LEN; i++)
 		sprintf(&digest_str[2 * i], "%02x", digest[i]);
 	digest_str[SHA256STRLEN - 1] = '\0';
 	// Is it in whitelist?
@@ -975,7 +905,7 @@ static int ssl_verify_cert(struct tunnel *tunnel)
 	log_error("    subject:\n");
 	subject = X509_NAME_oneline(subj, NULL, 0);
 	if (subject) {
-		for (line = strtok_r(subject, "/", &saveptr); line != NULL;
+		for (char *line = strtok_r(subject, "/", &saveptr); line != NULL;
 		     line = strtok_r(NULL, "/", &saveptr))
 			log_error("        %s\n", line);
 		free(subject);
@@ -983,7 +913,7 @@ static int ssl_verify_cert(struct tunnel *tunnel)
 	log_error("    issuer:\n");
 	issuer = X509_NAME_oneline(X509_get_issuer_name(cert), NULL, 0);
 	if (issuer) {
-		for (line = strtok_r(issuer, "/", &saveptr); line != NULL;
+		for (char *line = strtok_r(issuer, "/", &saveptr); line != NULL;
 		     line = strtok_r(NULL, "/", &saveptr))
 			log_error("        %s\n", line);
 		free(issuer);
@@ -997,7 +927,7 @@ free_cert:
 }
 
 /*
- * Destroy and free the SSL connection to the gateway.
+ * Destroy and free the TLS connection to the gateway.
  */
 static void ssl_disconnect(struct tunnel *tunnel)
 {
@@ -1012,7 +942,7 @@ static void ssl_disconnect(struct tunnel *tunnel)
 	tunnel->ssl_context = NULL;
 
 	if (close(tunnel->ssl_socket))
-		log_warn("Could not close ssl socket (%s).\n", strerror(errno));
+		log_warn("Could not close TLS socket (%s).\n", strerror(errno));
 	tunnel->ssl_socket = -1;
 }
 
@@ -1052,7 +982,7 @@ static int pem_passphrase_cb(char *buf, int size, int rwflag, void *u)
 }
 
 /*
- * Connects to the gateway and initiate an SSL session.
+ * Connects to the gateway and initiate a TLS session.
  */
 int ssl_connect(struct tunnel *tunnel)
 {
@@ -1268,6 +1198,17 @@ int ssl_connect(struct tunnel *tunnel)
 	}
 	SSL_set_mode(tunnel->ssl_handle, SSL_MODE_AUTO_RETRY);
 
+
+	// Set SNI for the session
+	const char *sni = tunnel->config->sni[0] ? tunnel->config->sni :
+	                  tunnel->config->gateway_host;
+	if (SSL_set_tlsext_host_name(tunnel->ssl_handle, sni) != 1)
+		log_warn("SSL_set_tlsext_host_name('%s'): %s\n",
+		         sni,
+		         ERR_error_string(ERR_peek_last_error(), NULL));
+	else
+		log_debug("Set SNI for TLS handshake: %s\n", sni);
+
 	// Initiate SSL handshake
 	if (SSL_connect(tunnel->ssl_handle) != 1) {
 		log_error("SSL_connect: %s\n"
@@ -1295,7 +1236,7 @@ err_ssl_context:
 	tunnel->ssl_context = NULL;
 err_ssl_socket:
 	if (close(tunnel->ssl_socket))
-		log_warn("Could not close ssl socket (%s).\n", strerror(errno));
+		log_warn("Could not close TLS socket (%s).\n", strerror(errno));
 	tunnel->ssl_socket = -1;
 err_tcp_connect:
 	return 1;
@@ -1323,8 +1264,8 @@ int run_tunnel(struct vpn_config *config)
 	if (ret)
 		goto err_tunnel;
 
-	// Step 1: open a SSL connection to the gateway
-	log_debug("Establishing ssl connection\n");
+	// Step 1: open a TLS connection to the gateway
+	log_debug("Establishing TLS connection\n");
 	ret = ssl_connect(&tunnel);
 	if (ret)
 		goto err_tunnel;
